@@ -52,8 +52,9 @@ bool ProcessesLocal::Private::readProc(long pid, struct kinfo_proc *p)
     mib[3] = pid;
 
     len = sizeof(struct kinfo_proc);
-    if (sysctl(mib, 4, p, &len, NULL, 0) == -1 || !len)
+    if (sysctl(mib, 4, p, &len, NULL, 0) == -1 || !len) {
         return false;
+    }
     return true;
 }
 
@@ -121,8 +122,9 @@ bool ProcessesLocal::Private::readProcCmdline(long pid, Process *process)
     mib[2] = KERN_PROC_ARGS;
     mib[3] = pid;
 
-    if (sysctl(mib, 4, buf, &buflen, NULL, 0) == -1 || !buflen)
+    if (sysctl(mib, 4, buf, &buflen, NULL, 0) == -1 || !buflen) {
         return false;
+    }
     QString command = QString::fromUtf8(buf);
 
     // cmdline separates parameters with the NULL character
@@ -150,13 +152,15 @@ long ProcessesLocal::getParentPid(long pid)
 bool ProcessesLocal::updateProcessInfo(long pid, Process *process)
 {
     struct kinfo_proc p;
-    if (!d->readProc(pid, &p))
+    if (!d->readProc(pid, &p)) {
         return false;
+    }
     d->readProcStat(&p, process);
     d->readProcStatus(&p, process);
     d->readProcStatm(&p, process);
-    if (!d->readProcCmdline(pid, process))
+    if (!d->readProcCmdline(pid, process)) {
         return false;
+    }
 
     return true;
 }
@@ -172,10 +176,12 @@ QSet<long> ProcessesLocal::getAllPids()
     mib[0] = CTL_KERN;
     mib[1] = KERN_PROC;
     mib[2] = KERN_PROC_ALL;
-    if (sysctl(mib, 3, NULL, &len, NULL, 0) == -1)
+    if (sysctl(mib, 3, NULL, &len, NULL, 0) == -1) {
         return pids;
-    if ((p = (kinfo_proc *)malloc(len)) == NULL)
+    }
+    if ((p = (kinfo_proc *)malloc(len)) == NULL) {
         return pids;
+    }
     if (sysctl(mib, 3, p, &len, NULL, 0) == -1) {
         free(p);
         return pids;
@@ -186,8 +192,9 @@ QSet<long> ProcessesLocal::getAllPids()
         long long ppid = p[num].ki_ppid;
 
         // skip all process with parent id = 0 but init
-        if (ppid <= 0 && pid != 1)
+        if (ppid <= 0 && pid != 1) {
             continue;
+        }
         pids.insert(pid);
     }
     free(p);
@@ -214,10 +221,12 @@ Processes::Error ProcessesLocal::setNiceness(long pid, int priority)
 
 Processes::Error ProcessesLocal::setScheduler(long pid, int priorityClass, int priority)
 {
-    if (priorityClass == KSysGuard::Process::Other || priorityClass == KSysGuard::Process::Batch)
+    if (priorityClass == KSysGuard::Process::Other || priorityClass == KSysGuard::Process::Batch) {
         priority = 0;
-    if (pid <= 0)
+    }
+    if (pid <= 0) {
         return Processes::InvalidPid; // check the parameters
+    }
     struct sched_param params;
     params.sched_priority = priority;
     bool success = false;
@@ -259,8 +268,9 @@ long long ProcessesLocal::totalPhysicalMemory()
     size_t len;
 
     len = sizeof(Total);
-    if (sysctlbyname("hw.physmem", &Total, &len, NULL, 0) == -1)
+    if (sysctlbyname("hw.physmem", &Total, &len, NULL, 0) == -1) {
         return 0;
+    }
 
     return Total /= 1024;
 }
